#################
Analytics Queries
#################

.. currentmodule:: couchbase.analytics

.. class:: AnalyticsQuery

    .. automethod:: __init__

.. class:: AnalyticsResult

    .. automethod:: __init__

.. not defined by SDK3 Analytics RFC

.. .. class:: DeferredAnalyticsQuery

   .. .. automethod:: __init__
    .. automethod:: set_option
    .. autoattribute:: encoded

.. .. class:: DeferredAnalyticsRequest

    .. .. automethod:: __init__
    .. automethod:: __iter__
    .. automethod:: execute
    .. autoattribute:: meta
    .. automethod:: get_single_result

.. .. currentmodule:: couchbase.analytics_ingester

.. .. class:: AnalyticsIngester

    .. .. automethod:: __init__
    .. automethod:: __call__

